b2luigi.batch package
=====================

.. autoclass:: b2luigi.batch.processes.BatchProcess
    :members: get_job_status, start_job, kill_job

.. autoclass:: b2luigi.batch.processes.lsf.LSFProcess
    :show-inheritance:

